@@ -106,7 +106,7 @@ class OTXv2(object):
         self.request_session = None
         self.headers = {
             'X-OTX-API-KEY': self.key,
-            'User-Agent': user_agent or 'OTX Python {}/1.5.9'.format(project),
+            'User-Agent': user_agent or 'OTX Python {}/1.5.10'.format(project),
             'Content-Type': 'application/json'
         }
 
@@ -118,7 +118,7 @@ class OTXv2(object):
             self.request_session.mount('https://', HTTPAdapter(
                 max_retries=Retry(
                     total=5,
-                    status_forcelist=[429, 500, 502, 503],
+                    status_forcelist=[429, 500, 502, 503, 504],
                     backoff_factor=1,
                 )
             ))
